@@ -27,6 +27,7 @@ class Team:
     :param self.num_donations: The total amount of donations to the team.
     :param self.top_5_participant_list: The top 5 participants in the team
     :param self.participant_list: a list of the most recent participants
+    :param self.team_avatar_image: The team's avatar
     """
 
     def __init__(self, team_id: str, output_folder: str, currency_symbol: str, donors_to_display:str):
@@ -48,6 +49,7 @@ class Team:
         self.team_captain: str = ""
         self.total_raised: int = 0
         self.num_donations: int = 0
+        self.team_avatar_image: str = ''
         # donor info
         self.participant_calculation_dict: dict = {}
         self.top_5_participant_list: List[TeamParticipant] = []
@@ -148,11 +150,14 @@ class Team:
     def donation_run(self) -> None:
         """Get and calculate donation information."""
         self.donation_list = donation.get_donations(self.donation_list, self.team_donation_url)
-        self.donation_formatted_output = donation.format_donation_information_for_output(self.donation_list,
-                                                                                         self.currency_symbol,
-                                                                                         self.donors_to_display,
-                                                                                         team=True)
-        self.write_text_files(self.donation_formatted_output)
+        if self.donation_list:
+            self.donation_formatted_output = donation.format_donation_information_for_output(self.donation_list,
+                                                                                             self.currency_symbol,
+                                                                                             self.donors_to_display,
+                                                                                             team=True)
+            self.write_text_files(self.donation_formatted_output)
+            team_avatar_for_html = "<img src=http:" + self.team_avatar_image + ">"
+            extralife_io.write_html_files(team_avatar_for_html, 'Team_Avatar', self.output_folder)
 
     def __str__(self):
         team_info = ""
